@@ -100,14 +100,16 @@ class RulesCollection(object):
     def extend(self, more):
         self.rules.extend(more)
 
-    def run(self, playbookfile, tags=set(), skip_tags=set()):
+    def run(self, playbookfile, tags=set(), skip_list=set()):
         text = ""
         matches = list()
         with open(playbookfile['path'], 'Ur') as f:
             text = f.read()
         for rule in self.rules:
             if not tags or not set(rule.tags).isdisjoint(tags):
-                if set(rule.tags).isdisjoint(skip_tags):
+                rule_definition = set(rule.tags)
+                rule_definition.add(rule.id)
+                if set(rule_definition).isdisjoint(skip_list):
                     matches.extend(rule.matchlines(playbookfile, text))
                     matches.extend(rule.matchtasks(playbookfile, text))
                     matches.extend(rule.matchyaml(playbookfile, text))
@@ -152,22 +154,44 @@ class Match:
 
 class Runner:
 
-    def __init__(self, rules, playbooks, tags, skip_tags):
+    def __init__(self, rules, playbooks, tags, skip_list, exclude_paths):
         self.rules = rules
         self.playbooks = set()
         for pb in playbooks:
             self.playbooks.add((pb, 'playbook'))
         self.tags = tags
-        self.skip_tags = skip_tags
+        self.skip_list = skip_list
+        self._update_exclude_paths(exclude_paths)
+
+    def _update_exclude_paths(self, exclude_paths):
+        if exclude_paths:
+            # These will be (potentially) relative paths
+            paths = [s.strip() for s in exclude_paths]
+            # Since ansiblelint.utils.find_children returns absolute paths,
+            # and the list of files we create in `Runner.run` can contain both
+            # relative and absolute paths, we need to cover both bases.
+            self.exclude_paths = paths + [os.path.abspath(p) for p in paths]
+        else:
+            self.exclude_paths = []
+
+    def is_excluded(self, file_path):
+        # Any will short-circuit as soon as something returns True, but will
+        # be poor performance for the case where the path under question is
+        # not excluded.
+        return any(file_path.startswith(path) for path in self.exclude_paths)
 
     def run(self):
         files = list()
         for playbook in self.playbooks:
+            if self.is_excluded(playbook[0]):
+                continue
             files.append({'path': playbook[0], 'type': playbook[1]})
         visited = set()
         while (visited != self.playbooks):
             for arg in self.playbooks - visited:
                 for file in ansiblelint.utils.find_children(arg):
+                    if self.is_excluded(file['path']):
+                        continue
                     self.playbooks.add((file['path'], file['type']))
                     files.append(file)
                 visited.add(arg)
@@ -175,6 +199,6 @@ class Runner:
         matches = list()
         for file in files:
             matches.extend(self.rules.run(file, tags=set(self.tags),
-                           skip_tags=set(self.skip_tags)))
+                           skip_list=set(self.skip_list)))
 
         return matches
